==> jc-1.4.0.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__241.h <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class baf94dac421c34e3 org_w3c_dom_bootstrap_DOMImplementationRegistry__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object;

typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$_init$16416901d23908e2(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_util_Vector$object *);

// Virtual methods
extern jint _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *);
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$item$ad3f93e30f338189(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method_info$item$ad3f93e30f338189;

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *);
	struct _jc_object	*(*item$ad3f93e30f338189)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, jint);
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs {
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object	*this;
	struct _jc_java_util_Vector$object	*val__24implementations;
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__241.h <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class baf94dac421c34e3 org_w3c_dom_bootstrap_DOMImplementationRegistry__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;
struct _jc_org_w3c_dom_DOMImplementation$object;
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object;

typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$_init$16416901d23908e2(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object *, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method$item$ad3f93e30f338189(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$method_info$item$ad3f93e30f338189;

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods {
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*item$ad3f93e30f338189)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs {
	struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry$object	*this;
	struct _jc_java_util_Vector$object	*val__24implementations;
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry__241;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__241$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__241_H_ */
